﻿using System;
using System.Threading;
using System.Configuration;
using Alachisoft.NCache.Runtime.Dependencies;
using Alachisoft.NCache.Web.Caching;

// ===============================================================================
// Alachisoft (R) NCache Sample Code.
// NCache Oracle Dependency Sample.
// ===============================================================================
// Copyright © Alachisoft.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
// ===============================================================================


namespace Dependency
{
	public class OracleDependency
	{
		public static void RunOracleDependencyDemo()
		{
			try
			{
				//Initialize cache
				Cache cache;
				cache = NCache.InitializeCache("mypartitionedcache");
				cache.Clear();

				//change notification previleges must be granted for OracleDBDependency to work
				//-- run this script
				//-- 'grant change notification to username' without quotes where username 
				//is to replaced with one being used by the db instance

				//Notification based DBDependency
				//JDBC connectionString                         

                string connectionString = ConfigurationManager.AppSettings["ConnectionString"];
				string commandText = "SELECT PRODUCTID, rowId, PRODUCTNAME FROM PRODUCTS WHERE PRODUCTID = 1";

				CacheDependency oracleDependency = new OracleCacheDependency(connectionString, commandText);

				CacheItem cacheItem = new CacheItem("OracleDependentValue");
				cacheItem.Dependency = oracleDependency;

				cache.Add("Item:1", cacheItem);

				Thread.Sleep(20000);

				if (cache.Contains("Item:1"))
				{
					Console.WriteLine("Oracle dependency did not work as expected. " + "Check your connection string and sql command syntax.");
				}
				else
				{
					Console.WriteLine("Item:1 removed due to oracle dependency.");
				}

				//Must dispose cache
				cache.Dispose();


			}
			catch (Exception ex)
			{
				Console.Write(ex.Message);
			}
		}

	}

}